@@ -1,9 +1,14 @@
+
+static const char cright_years_z[] =
+
 /* Handle so called `shell archives'.
-   Copyright (C) 1994, 1995, 1996, 2002, 2005 Free Software Foundation, Inc.
+   Copyright (C) */ "1994, 1995, 1996, 2002, 2005, 2006, 2007, 2010";
+
+/* Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -12,8 +17,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+   along with this program; if not, see:  http://www.gnu.org/licenses.
 */
 
 /* Unpackage one or more shell archive files.  The `unshar' program is a
@@ -22,20 +26,14 @@
    knows about shell comment characters and the Unix commands `echo',
    `cat', and `sed'.  */
 
-#include "system.h"
-#include "getopt.h"
-#include "basename.h"
-#include "error.h"
-#include "exit.h"
-#include "stpcpy.h"
+#include "local.h"
+
 #include "xgetcwd.h"
 
 #if HAVE_LOCALE_H
-# include <locale.h>
 #else
 # define setlocale(Category, Locale)
 #endif
-#include "gettext.h"
 #define _(str) gettext (str)
 
 /* Buffer size for shell process input.  */
@@ -416,7 +414,7 @@ main (argc, argv)
 This is free software; see the source for copying conditions.  There is NO\n\
 warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n\
 "),
-	      "1994, 1995, 1996, 2005");
+	      cright_years_z);
       exit (EXIT_SUCCESS);
     }
 
